@@ -213,7 +213,7 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
         def CreateControls(self, propGrid, property, pos, sz):
             buttons = wxpg.PGMultiButton(propGrid, sz)
             dataValid = (property.env['dsrepo'].get_resource(property.path) != None)
-            self._AddCustomButtons(buttons, dataValid)
+            self._AddCustomButtons(buttons, dataValid, property)
             if dataValid:
                 if not property.schemaNode.mandatory:
                     buttons.AddBitmapButton(wx.ArtProvider.GetBitmap(wx.ART_MINUS), id=self.DELETE)
@@ -242,7 +242,7 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
 
             return wxpg.PGWindowList(wndList.GetPrimary(), buttons)
 
-        def _AddCustomButtons(self, buttons, dataValid):
+        def _AddCustomButtons(self, buttons, dataValid, property):
             pass
 
         class AdvancedMenu(wx.Menu):
@@ -261,14 +261,30 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
                         'create': False,
                         'tooltip': 'Add to graph',
                         'cb': self._OnAddToGraph
+                    },
+                    'GET_LIST': {
+                        'kind': wx.ITEM_NORMAL,
+                        'create': False,
+                        'tooltip': 'GET entire list',
+                        'cb': self._OnGetList
+                    },
+                    'PUT_LIST': {
+                        'kind': wx.ITEM_NORMAL,
+                        'create': False,
+                        'tooltip': 'PUT entire list',
+                        'cb': self._OnPutList
                     }
                 }
                 if isinstance(prop.schemaNode, yangson.schemanode.LeafNode) and isinstance(prop.schemaNode.type, yangson.datatype.NumericType):
                     self.items['ADD_TO_GRAPH']['create'] = True
                 if (prop.env['southboundIf'] != None) and (prop.env['southboundIf'].resources != None):
                     if prop.schemaNode.data_path() in prop.env['southboundIf'].resources:
-                        if not prop.schemaNode.config:
-                            self.items['GET_LOOP']['create'] = True
+                        self.items['GET_LOOP']['create'] = True
+                        if prop.schemaNode.config:
+                            if isinstance(prop.schemaNode, yangson.schemanode.ListNode):
+                                self.items['PUT_LIST']['create'] = True
+                        if isinstance(prop.schemaNode, yangson.schemanode.ListNode):
+                            self.items['GET_LIST']['create'] = True
 
                 self._AddItems()
                 self._ShowAdvancedOptions()
@@ -308,6 +324,18 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
                 else:
                     self.prop.env['graphViewer'].remove(self.prop.topic)
 
+            def _OnPutList(self, e):
+                data = self.prop.env['dsrepo'].get_resource(self.prop.listPath)
+                if self.prop.env['southboundIf'] != None:
+                    self.prop.env['southboundIf'].put(self.prop.env['dsrepo'].dm, data, self.prop.listPath)
+
+            def _OnGetList(self, e):
+                if self.prop.env['southboundIf'] != None:
+                    data = self.prop.env['dsrepo'].get_resource(self.prop.listPath)
+                    data = self.prop.env['southboundIf'].get(self.prop.env['dsrepo'].dm, data, self.prop.listPath)
+                    if data != None:
+                        self.prop.env['dsrepo'].commit(data.top())                    
+
         def OnEvent(self, propGrid, aProperty, ctrl, event):
             if event.GetEventType() == wx.wxEVT_BUTTON:
                 evtId = event.GetId()
@@ -362,19 +390,35 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
 
     class YangListEditor(YangEditor, wxpg.PGTextCtrlEditor):
         LISTEDIT = wx.ID_HIGHEST + 20
+        LISTNEXT = wx.ID_HIGHEST + 21
+        LISTPREVIOUS = wx.ID_HIGHEST + 22
         def __init__(self):
             wxpg.PGTextCtrlEditor.__init__(self)
             YangPropertyGrid.YangEditor.__init__(self)
 
-        def _AddCustomButtons(self, buttons, dataValid):
+        def _AddCustomButtons(self, buttons, dataValid, property):
             if dataValid:
                 self._tooltips[self.LISTEDIT] = 'Launch viewer for this list'
                 buttons.Add("...", id=self.LISTEDIT)
+                if property.index > 0:
+                    self._tooltips[self.LISTPREVIOUS] = 'Select previous entry in this list'
+                    buttons.Add("<", id=self.LISTPREVIOUS)
+                if property.index < property.max_index:
+                    self._tooltips[self.LISTNEXT] = 'Select next entry in this list'
+                    buttons.Add(">", id=self.LISTNEXT)
 
         def OnEvent(self, propGrid, aProperty, ctrl, event):
             if (event.GetEventType() == wx.wxEVT_BUTTON) and (event.GetId() == self.LISTEDIT):
                 lv = YangListViewer(aProperty)
                 lv.Show()
+                return False
+            if (event.GetEventType() == wx.wxEVT_BUTTON) and (event.GetId() == self.LISTNEXT):
+                aProperty.Select(aProperty.index + 1)
+                aProperty.RecreateEditor()
+            if (event.GetEventType() == wx.wxEVT_BUTTON) and (event.GetId() == self.LISTPREVIOUS):
+                aProperty.Select(aProperty.index - 1)
+                aProperty.RecreateEditor()
+                
                 return False
             return super().OnEvent(propGrid, aProperty, ctrl, event)
 
@@ -419,15 +463,15 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
             return lb
 
         def _GetUpdatedData(self, data):
-            return data.update(self.lb.CheckedStrings).top()
+            return data.update(self.ctrl.CheckedStrings).top()
 
     class YangBitsEditor(YangEditor, wxpg.PGTextCtrlEditor):
-        BITSEDIT = wx.ID_HIGHEST + 22
+        BITSEDIT = wx.ID_HIGHEST + 30
         def __init__(self):
             wxpg.PGTextCtrlEditor.__init__(self)
             YangPropertyGrid.YangEditor.__init__(self)
 
-        def _AddCustomButtons(self, buttons, dataValid):
+        def _AddCustomButtons(self, buttons, dataValid, property):
             if dataValid:
                 self._tooltips[self.BITSEDIT] = 'Launch editor dialog for bits data node'
                 buttons.Add("...", id=self.BITSEDIT)
@@ -457,12 +501,12 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
             return data.update(yangson.instvalue.ArrayValue(val=values)).top()
 
     class YangLeafListEditor(YangEditor, wxpg.PGTextCtrlEditor):
-        LEAFLISTEDIT = wx.ID_HIGHEST + 21
+        LEAFLISTEDIT = wx.ID_HIGHEST + 31
         def __init__(self):
             wxpg.PGTextCtrlEditor.__init__(self)
             YangPropertyGrid.YangEditor.__init__(self)
 
-        def _AddCustomButtons(self, buttons, dataValid):
+        def _AddCustomButtons(self, buttons, dataValid, property):
             if dataValid:
                 self._tooltips[self.LEAFLISTEDIT] = 'Launch editor dialog for this leaf list'
                 buttons.Add("...", id=self.LEAFLISTEDIT)
@@ -641,8 +685,6 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
                     if len(interval) == 2:
                         self.minLength = interval[0]
                         self.maxLength = interval[1]
-                        
-                        print(self.schemaNode.iname())
                     else:
                         self.minLength = interval[0]
 
@@ -848,6 +890,7 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
     class YangListProperty(YangInternalProperty):
         def __init__(self, parent, sn):
             self.index = 0
+            self.max_index = 0
             super().__init__(parent, sn)
 
         def _SetEditor(self):
@@ -864,8 +907,9 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
             self.RefreshInstData()
 
         def Select(self, index):
-            self.index = index
-            self.RefreshInstData()
+            if index >= 0 and index <= self.max_index:
+                self.index = index
+                self.RefreshInstData()
 
         def RefreshInstData(self):
             data = self.env['dsrepo'].get_resource(self.listPath)
@@ -882,6 +926,7 @@ class YangPropertyGrid(wxpg.PropertyGridManager):
             self.DisplayYangEntryInstData(data)
 
         def DisplayYangEntryInstData(self, data):
+            self.max_index = len(data.parinst.value) - 1
             super().DisplayYangInstData(data)
             
         def DisplayYangInstData(self, data):
